@@ -1,7 +1,6 @@
-from fastapi import APIRouter, FastAPI
-from starlette.requests import Request
-from starlette.responses import JSONResponse
-from starlette.testclient import TestClient
+from fastapi import APIRouter, FastAPI, Request
+from fastapi.responses import JSONResponse
+from fastapi.testclient import TestClient
 
 app = FastAPI()
 router = APIRouter()
