@@ -2,8 +2,8 @@ from base64 import b64encode
 
 from fastapi import FastAPI, Security
 from fastapi.security import HTTPBasic, HTTPBasicCredentials
+from fastapi.testclient import TestClient
 from requests.auth import HTTPBasicAuth
-from starlette.testclient import TestClient
 
 app = FastAPI()
 
